@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Cochise Ruhulessin
+# Copyright (C) 2020-2023 Cochise Ruhulessin
 #
 # All rights reserved. No warranty, explicit or implicit, provided. In
 # no event shall the author(s) be liable for any claim or damages.
@@ -9,8 +9,11 @@
 import os
 
 
-AORTA_BACKEND: str = os.getenv('AORTA_BACKEND', 'local')
+__all__: list[str] = [
+    'GOOGLE_DATASTORE_NAMESPACE',
+    'GOOGLE_SERVICE_PROJECT',
+]
 
-AORTA_COMMAND_TOPIC: str | None = os.getenv('AORTA_COMMAND_TOPIC')
 
-AORTA_EVENT_TOPIC: str | None = os.getenv('AORTA_EVENT_TOPIC')
\ No newline at end of file
+GOOGLE_DATASTORE_NAMESPACE: str | None = os.environ.get('GOOGLE_DATASTORE_NAMESPACE')
+GOOGLE_SERVICE_PROJECT: str | None = os.environ.get('GOOGLE_SERVICE_PROJECT')
\ No newline at end of file
